#
# spec file for package python-dnspython
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

%define mod_name dnspython

Name:           python-%{mod_name}
Version:        1.10.0
Release:        2.1
Url:            http://www.dnspython.org/
Summary:        A DNS toolkit for Python
License:        ISC
Group:          Development/Languages/Python
Source:         http://www.dnspython.org/kits/1.10.0/%{mod_name}-%{version}.tar.gz
Source2:        http://www.dnspython.org/kits/1.10.0/%{mod_name}-%{version}.tar.gz.asc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
%if 0%{?suse_version}
%py_requires
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif
%endif

%description
dnspython is a DNS toolkit for Python. It supports almost all record
types. It can be used for queries, zone transfers,
and dynamic updates.  It supports TSIG authenticated messages and EDNS0.

dnspython provides both high and low level access to DNS. The high level classes
perform queries for data of a given name, type, and class, and return an answer
set.  The low level classes allow direct manipulation of DNS zones, messages,
names, and records.

%prep
%setup -q -n %{mod_name}-%{version}

%build
export CFLAGS="%{optflags}"
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root)
# You may have to add additional files here (documentation and binaries mostly)
%python_sitelib/dns*
%if 0%{?sles_version} != 10
%python_sitelib/*.egg-info
%endif
%doc README ChangeLog
%doc examples
%doc tests

%changelog
* Thu May 31 2012 cfarrell@suse.com
- license update: ISC
  See LICENSE (and compare http://www.spdx.org/licenses/MIT with
  http://www.spdx.org/licenses/ISC)
* Thu May 31 2012 jengelh@inai.de
- Update to new upstream release 1.10.0
  * Added dns.resolver.LRUCache.
  * dns.resolver.query() will try TCP if a UDP response is truncated.
  * The python socket module's DNS methods can be now be overriden
  with implementations that use dnspython's resolver.
- Remove redundant tags/sections from specfile
- Correct license field
* Mon Mar 28 2011 alexandre@exatati.com.br
- Update to 1.9.4:
  - There is no new functionality in this release;
    just a few bug fixes in RRSIG and SIG code.
  - Legacy code will be eliminated for earlier versions of
    DNSSEC in a future release of dnspython.
* Thu Mar 24 2011 alexandre@exatati.com.br
- Fix SLE_10 build.
* Thu Mar 24 2011 alexandre@exatati.com.br
- Update to 1.9.3:
  Bugs fixed since 1.9.2:
  - Dnspython was erroneously doing case-insensitive comparisons
    of the names in NSEC and RRSIG RRs.
  - We now use "is" and not "==" when testing what section an RR
    is in.
  - The resolver now disallows metaqueries.
  New since 1.9.2:
  - A boolean parameter, 'raise_on_no_answer', has been added to
    the query() methods.  In no-error, no-data situations, this
    parameter determines whether NoAnswer should be raised or not.
    If True, NoAnswer is raised.  If False, then an Answer()
    object with a None rrset will be returned.
  - Resolver Answer() objects now have a canonical_name field.
  - Rdata now have a __hash__ method.
- Regenerated spec file with py2pack;
- Removed LICENSE PKG-INFO and TODO files from documentation.
* Tue Nov 23 2010 alexandre@exatati.com.br
- Update to 1.9.2:
  - The fix for the import problems was actually bad, but didn't
    show up in testing because the test suite's conditional
    importing code hid the problem.
* Mon Nov 22 2010 alexandre@exatati.com.br
- Update to 1.9.1:
  Bugs fixed since 1.9.0:
  - The dns.dnssec module didn't work with DSA due to namespace
    contamination from a "from"-style import.
* Mon Nov 22 2010 alexandre@exatati.com.br
- Update to 1.9.0:
  New since 1.8.0:
  - dnspython now uses poll() instead of select() when available.
  - Basic DNSSEC validation can be done using dns.dnsec.validate()
    and dns.dnssec.validate_rrsig() if you have PyCrypto 2.3 or
    later installed. Complete secure resolution is not yet
    available.
  - Added key_id() to the DNSSEC module, which computes the DNSSEC
    key id of a DNSKEY rdata.
  - Added make_ds() to the DNSSEC module, which returns the DS RR
    for a given DNSKEY rdata.
  - dnspython now raises an exception if HMAC-SHA284 or
    HMAC-SHA512 are used with a Python older than 2.5.2. (Older
    Pythons do not compute the correct value.)
  - Symbolic constants are now available for TSIG algorithm names.
  Bugs fixed since 1.8.0:
  - dns.resolver.zone_for_name() didn't handle a query response
    with a CNAME or DNAME correctly in some cases.
  - When specifying rdata types and classes as text, Unicode
    strings may now be used.
  - Hashlib compatibility issues have been fixed.
  - dns.message now imports dns.edns.
  - The TSIG algorithm value was passed incorrectly to use_tsig()
    in some cases.
* Wed Jan 27 2010 alexandre@exatati.com.br
- Update to 1.8.0;
- Building as noarch for openSUSE >= 11.2.
* Fri Jan 19 2007 judas_iscariote@shorewall.net
- update to version 1.5.0
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue May 31 2005 poeml@suse.de
- package created (1.3.3)
